@@ -7,6 +7,8 @@
 ##' @param end a numeric vector. End position to plot.
 ##' @param font font families, possible values are 'helvetical', 'mono', and 'DroidSansMono', 'TimesNewRoman'.  Defaults is 'helvetical'. If font = NULL, only plot the background tile.
 ##' @param color a Color scheme. One of 'Clustal', 'Chemistry_AA', 'Shapely_AA', 'Zappo_AA', 'Taylor_AA', 'LETTER', 'CN6', 'Chemistry_NT', 'Shapely_NT', 'Zappo_NT', 'Taylor_NT'. Defaults is 'Chemistry_AA'.
+##' @param custom_color A data frame with two cloumn called "names" and "color".Customize the color scheme.
+##' @param order vectors.Specified sequences order.
 ##' @param char_width a numeric vector. Specifying the character width in the range of 0 to 1. Defaults is 0.9.
 ##' @param by_conservation a logical value. The most conserved regions have the brightest colors.
 ##' @param none_bg a logical value indicating whether background should be disaplayed. Defaults is FALSE.
@@ -53,14 +55,14 @@
 ##' @export
 ##' @author Guangchuang Yu
 ggmsa <- function(msa, start = NULL, end = NULL, font = "helvetical",
-                  color = "Chemistry_AA", char_width = 0.9, none_bg = FALSE, by_conservation = FALSE,
+                  color = "Chemistry_AA", custom_color = NULL, order = NULL, char_width = 0.9, none_bg = FALSE, by_conservation = FALSE,
                   posHighligthed = NULL, seq_name = NULL, border = NULL, consensus_views = FALSE, use_dot = FALSE,
                   disagreement = TRUE, ignore_gaps = FALSE, ref = NULL) {
     data <- tidy_msa(msa, start = start, end = end)
 
-    ggplot() + geom_msa(data, font = font, color = color, char_width = char_width, none_bg = none_bg, by_conservation = by_conservation,
-                        posHighligthed = posHighligthed, seq_name = seq_name, border = border, consensus_views = consensus_views,
-                        use_dot = use_dot, disagreement = disagreement, ignore_gaps = ignore_gaps, ref = ref) +
+    ggplot() + geom_msa(data, font = font, color = color, custom_color = custom_color, order = order, char_width = char_width, none_bg = none_bg,
+                        by_conservation = by_conservation, posHighligthed = posHighligthed, seq_name = seq_name, border = border,
+                        consensus_views = consensus_views,use_dot = use_dot, disagreement = disagreement, ignore_gaps = ignore_gaps, ref = ref) +
                theme_msa()
 
 }
